==> qmmp_0.5.1.orig.tar.gz: qmmp-0.5.1/src/plugins/Input/cdaudio/translations/cdaudio_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>DecoderCDAudioFactory</name>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="45"/>
        <source>CD Audio Plugin</source>
        <translation>CD 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="88"/>
        <source>About CD Audio Plugin</source>
        <translation>關於 CD 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="89"/>
        <source>Qmmp CD Audio Plugin</source>
        <translation>Qmmp CD 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="90"/>
        <source>Compiled against libcdio-%1 and libcddb-%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="92"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="93"/>
        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
        <translation>用法：open cdda:/// 使用添加 URL會話或命令行</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CD Audio Plugin Settings</source>
        <translation>CD 聲訊插件設置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Override device:</source>
        <translation>忽略設備：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Limid cd speed:</source>
        <translation>限制 CD 速度：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Use cd-text</source>
        <translation>使用 cd-text</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>CDDB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Use HTTP instead of CDDBP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="88"/>
        <source>Server:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Clear CDDB cache</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_0.6.3.orig.tar.gz: qmmp-0.6.3/src/plugins/Input/cdaudio/translations/cdaudio_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>DecoderCDAudioFactory</name>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="45"/>
        <source>CD Audio Plugin</source>
        <translation>CD 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="88"/>
        <source>About CD Audio Plugin</source>
        <translation>關於 CD 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="89"/>
        <source>Qmmp CD Audio Plugin</source>
        <translation>Qmmp CD 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="90"/>
        <source>Compiled against libcdio-%1 and libcddb-%2</source>
        <translation>編譯依賴 libcdio-%1 and libcddb-%2</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="92"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="93"/>
        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
        <translation>用法：open cdda:/// 使用添加 URL會話或命令行</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CD Audio Plugin Settings</source>
        <translation>CD 聲訊插件設置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Override device:</source>
        <translation>忽略設備：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Limid cd speed:</source>
        <translation>限制 CD 速度：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Use cd-text</source>
        <translation>使用 cd-text</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>CDDB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Use HTTP instead of CDDBP</source>
        <translation>使用 HTTP 而非 CDDBP</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="88"/>
        <source>Server:</source>
        <translation>服務器：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Path:</source>
        <translation>路徑：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Port:</source>
        <translation>端口：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Clear CDDB cache</source>
        <translation>清除 CDDB 緩存</translation>
    </message>
</context>
</TS>
